redvox.api900.timesync API documentation

# Module `redvox.api900.timesync`

## Sub-modules

`redvox.api900.timesync.api900_timesync`

  Modules for extracting time synchronization statistics for API 900 data. Also includes functions for correcting time arrays.

`redvox.api900.timesync.tri_message_stats`

  Modules for extracting time synchronization statistics according to Tri-Message protocol. All functions assume payload for ONE data packet/decoder …